@@ -1,9 +1,15 @@
-#line 1 "inc/Module/Install/Build.pm - /usr/local/lib/perl5/site_perl/5.8.5/Module/Install/Build.pm"
+#line 1
 package Module::Install::Build;
-$VERSION = '0.01';
+
 use strict;
-use vars qw(@ISA);
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
+use Module::Install::Base;
+
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+	$VERSION = '0.63';
+	$ISCORE  = 1;
+	@ISA     = qw{Module::Install::Base};
+}
 
 sub Build { $_[0] }
 
@@ -14,14 +20,14 @@ sub write {
     my %args;
     my $build;
 
-    $args{dist_name} = $self->name || $self->determine_NAME($self->{args});
-    $args{license} = $self->license;
-    $args{test_files} = $self->tests;
-    $args{dist_version} = $self->version || $self->determine_VERSION($self->{args});
+    $args{dist_name}     = $self->name || $self->determine_NAME($self->{args});
+    $args{license}       = $self->license;
+    $args{test_files}    = $self->tests;
+    $args{dist_version}  = $self->version || $self->determine_VERSION($self->{args});
     $args{dist_abstract} = $self->abstract;
-    $args{dist_author} = $self->author;
-    $args{sign} = $self->sign;
-    $args{no_index} = $self->no_index;
+    $args{dist_author}   = $self->author;
+    $args{sign}          = $self->sign;
+    $args{no_index}      = $self->no_index;
 
     foreach my $key (qw(build_requires requires recommends conflicts)) {
         my $val = eval "\$self->$key" or next;
@@ -56,9 +62,8 @@ sub ACTION_dist {
 # <DrMath> ingy: then my $build = new MyBuilder( ...parameters... );
 #           $build->write_build_script;
 
-
 1;
 
 __END__
 
-#line 176
+#line 180
