@@ -8,6 +8,11 @@ use SVK::Util qw( get_prompt abs2rel abs_path is_uri catdir bsd_glob from_native
 use SVK::I18N;
 use Encode;
 
+use Class::Autouse
+    qw( SVK::Target SVK::Notify
+	SVK::Editor::Status SVK::Editor::Diff
+	Pod::Simple::Text SVK::Merge );
+
 =head1 NAME
 
 SVK::Command - Base class and dispatcher for SVK commands
@@ -559,6 +564,12 @@ Argument is a checkout path.
 sub arg_copath {
     my ($self, $arg) = @_;
     my ($repospath, $path, $copath, $cinfo, $repos) = $self->{xd}->find_repos_from_co ($arg, 1);
+
+    if ($copath =~ m/([\x00-\x19\x7f])/) { # XXX: why isn't \c[ working?
+	die loc("Invalid control character '%1' in path '%2'\n",
+		sprintf("0x%02X", ord($1)), $arg);
+    }
+
     from_native ($path, 'path', $self->{encoding});
     return SVK::Target->new
 	( repos => $repos,
@@ -583,7 +594,7 @@ sub arg_depotpath {
     my $rev = $arg =~ s/\@(\d+)$// ? $1 : undef;
     my ($repospath, $path, $repos) = $self->{xd}->find_repos ($arg, 1);
     from_native ($path, 'path', $self->{encoding});
-    return SVK::Target->new
+    my $target = SVK::Target->new
 	( repos => $repos,
 	  repospath => $repospath,
 	  path => $path,
@@ -591,6 +602,8 @@ sub arg_depotpath {
 	  revision => $rev,
 	  depotpath => $arg,
 	);
+    $target->{depotpath} = '/'.$target->depotname.$path;
+    return $target;
 }
 
 =head3 arg_depotroot ($arg)
@@ -968,7 +981,7 @@ sub resolve_revspec {
     my ($r1,$r2);
     if (my $revspec = $self->{revspec}) {
         if ($#{$revspec} > 1) {
-            die loc ("Invliad -r.\n");
+            die loc ("Invalid -r.\n");
         } else {
             $revspec = [map {split /:/} @$revspec];
             ($r1, $r2) = map {
