@@ -6,7 +6,6 @@ use base qw( SVK::Command::Merge SVK::Command::Copy SVK::Command::Propset );
 use SVK::XD;
 use SVK::I18N;
 use SVK::Editor::Combine;
-use SVK::Inspector::Compat;
 
 sub options {
     ($_[0]->SUPER::options);
@@ -32,12 +31,9 @@ sub run {
         print loc("%1 cmerge is deprecated, pending improvements to the Subversion API",$0) ."\n";
         print loc("'Use %1 merge -c' to obtain similar functionality.",$0)."\n\n";
     }
-    my @revlist = $self->parse_revlist($src);
-    for my $r (@revlist) {
-        die("Revision spec must be N:M.\n") unless defined($r->[1])
-    }
+    my @revlist = $self->parse_revlist;
 
-    my $repos = $src->repos;
+    my $repos = $src->{repos};
     my $fs = $repos->fs;
     my $base = SVK::Merge->auto (%$self, repos => $repos, src => $src, dst => $dst,
 				 ticket => 1)->{base};
@@ -58,7 +54,6 @@ sub run {
 					   );
 
     my $spool = SVN::Pool->new_default;
-    my $inspector = SVK::Inspector::Compat->new({$ceditor->callbacks});
     for (@revlist) {
 	my ($fromrev, $torev) = @$_;
 	print loc("Merging with base %1 %2: applying %3 %4:%5.\n",
@@ -67,8 +62,7 @@ sub run {
 	SVK::Merge->new (%$self, repos => $repos,
 			 base => $src->new (revision => $fromrev),
 			 src => $src->new (revision => $torev), dst => $dst,
-			)->run ($ceditor, 
-			        inspector => $inspector,
+			)->run ($ceditor, $ceditor->callbacks,
 				# XXX: should be base_root's rev?
 				cb_rev => sub { $fs->youngest_rev });
 	$spool->clear;
@@ -99,10 +93,8 @@ sub run {
 	$self->{message} = $oldmessage;
     }
 
-    my ($depot) = $src->depotname;
+    my ($depot) = $self->{xd}->find_depotname ($src->{depotpath});
     ++$self->{auto};
-    undef $self->{chgspec};
-    undef $self->{revspec};
     $self->SUPER::run ($src->new (path => $tmpbranch,
 				  depotpath => "/$depot$tmpbranch",
 				  revision => $fs->youngest_rev),
