@@ -12,6 +12,8 @@ use SVK::Util qw( HAS_SVN_MIRROR get_buffer_from_editor slurp_fh read_file
 		  find_svm_source tmpfile abs2rel find_prev_copy from_native to_native
 		  get_encoder );
 
+use Class::Autouse qw( SVK::Editor::Rename SVK::Editor::Merge );
+
 sub options {
     ('m|message=s'  => 'message',
      'F|file=s'     => 'message_file',
@@ -31,7 +33,7 @@ sub parse_arg {
     return $self->arg_condensed (@arg);
 }
 
-sub lock { $_[0]->lock_target ($_[1]) }
+sub lock { $_[0]->lock_coroot($_[1]) }
 
 sub target_prompt {
     loc('=== Targets to commit (you may delete items from it) ===');
@@ -328,9 +330,10 @@ sub committed_commit {
 	for my $copath ($self->{xd}{checkout}->find ($dataroot, {revision => qr/.*/})) {
 	    my $coinfo = $self->{xd}{checkout}->get ($copath);
 	    next if $coinfo->{'.deleted'};
-	    my $corev = $coinfo->{revision};
+	    my $orev = eval { $oldroot->node_created_rev (abs2rel ($copath, $dataroot => $coanchor, '/')) };
+	    defined $orev or next;
 	    # XXX: cache the node_created_rev for entries within $target->path
-	    next if $corev < $oldroot->node_created_rev (abs2rel ($copath, $dataroot => $coanchor, '/'));
+	    next if $coinfo->{revision} < $orev;
 	    $self->{xd}{checkout}->store_override ($copath, {revision => $rev});
 	}
 	# update checkout map with new revision
