@@ -63,7 +63,7 @@ sub parse_arg {
 
 sub lock {
     my $self = shift;
-    $self->lock_target ($_[-1]);
+    $self->lock_coroot($_[-1]);
 }
 
 sub handle_co_item {
@@ -231,6 +231,7 @@ SVK::Command::Copy - Make a versioned copy
 
  -r [--revision] REV    : act on revision REV instead of the head revision
  -p [--parent]          : create intermediate directories as required
+ -q [--quiet]           : print as little as possible
  -m [--message] MESSAGE : specify commit message MESSAGE
  -F [--file] FILENAME   : read commit message from FILENAME
  --template             : use the specified message as the template to edit
