@@ -15,11 +15,20 @@ sub parse_arg {
     my ($self, @arg) = @_;
     return if $#arg < 0;
     my $target;
-    if ($#arg == 0) {
-	$target = $self->arg_co_maybe ($arg[0]);
-	return $target unless $target->{copath};
+    @arg = map { $self->{xd}->target_from_copath_maybe($_) } @arg;
+
+    # XXX: better check for @target being the same type
+    if (grep {$_->{copath}} @arg) {
+	die loc("Mixed depotpath and checkoutpath not supported.\n")
+	    if grep {!$_->{copath}} @arg;
+
+	return $self->arg_condensed(map {$_->{report} } @arg);
     }
-    return $self->arg_condensed (@arg);
+
+    die loc("Delete for more than one depotpath is not supported yet.\n")
+	if scalar @arg > 1;
+
+    return @arg;
 }
 
 sub lock {
@@ -86,9 +95,15 @@ SVK::Command::Delete - Remove versioned item
 
 =head1 OPTIONS
 
- -m [--message] MESSAGE	: specify commit message MESSAGE
- -F [--file] FILENAME	: read commit message from FILENAME
  -K [--keep-local]      : do not remove the local file
+ -m [--message] MESSAGE : specify commit message MESSAGE
+ -F [--file] FILENAME   : read commit message from FILENAME
+ --template             : use the specified message as the template to edit
+ --encoding ENC         : treat -m/-F value as being in charset encoding ENC
+ -P [--patch] NAME      : instead of commit, save this change as a patch
+ -S [--sign]            : sign this change
+ -C [--check-only]      : try operation but make no changes
+ --direct               : commit directly even if the path is mirrored
 
 =head1 AUTHORS
 
