@@ -6,7 +6,9 @@ use base qw( SVK::Command );
 use constant opt_recursive => 0;
 use SVK::XD;
 use SVK::I18N;
-use SVK::Util qw( to_native get_encoder reformat_svn_date );
+use SVK::Util qw( to_native get_encoder );
+use Date::Parse qw(str2time);
+use Date::Format qw(time2str);
 
 sub options {
     ('r|revision=s'  => 'rev',
@@ -26,9 +28,7 @@ sub run {
     my $exception = '';
 
     while (my $arg = shift @arg) {
-	$arg = $arg->as_depotpath;
-        eval { _do_list($self, 0, $self->apply_revision($arg));
-	       print "\n" if @arg };
+        eval { _do_list($self, 0, $arg); print "\n" if @arg };
         $exception .= "$@" if $@;
     }
 
@@ -38,21 +38,24 @@ sub run {
 sub _do_list {
     my ($self, $level, $target) = @_;
     my $pool = SVN::Pool->new_default;
+    $target->as_depotpath ($self->resolve_revision($target,$self->{rev}));
     my $root = $target->root;
-    unless ((my $kind = $root->check_path ($target->path_anchor)) == $SVN::Node::dir) {
-       die loc("Path %1 is not a versioned directory\n", $target->path_anchor)
+    unless ((my $kind = $root->check_path ($target->{path})) == $SVN::Node::dir) {
+       die loc("Path %1 is not a versioned directory\n", $target->{path})
            unless $kind == $SVN::Node::file;
        return;
     }
 
-    my $entries = $root->dir_entries ($target->path_anchor);
+    # XXX: SVK::Target should take care of this.
+    $target->{depotpath} =~ s|/$||;
+    my $entries = $root->dir_entries ($target->{path});
     my $enc = get_encoder;
     for (sort keys %$entries) {
 	my $isdir = ($entries->{$_}->kind == $SVN::Node::dir);
 
         if ($self->{verbose}) {
-	    my $rev = $root->node_created_rev ($target->path."/$_");
-            my $fs = $target->repos->fs;
+	    my $rev = $root->node_created_rev ("$target->{path}/$_");
+            my $fs = $target->{'repos'}->fs;
 
             my $svn_date =
                 $fs->revision_prop ($rev, 'svn:date');
@@ -63,12 +66,12 @@ sub _do_list {
 	    # Additional fields for verbose: revision author size datetime
             printf "%7ld %-8.8s %10s %12s ", $rev,
                 $fs->revision_prop ($rev, 'svn:author'),
-                ($isdir) ? "" : $root->file_length ($target->path."/$_"),
-                reformat_svn_date("%b %d %H:%M", $svn_date);
+                ($isdir) ? "" : $root->file_length ("$target->{path}/$_"),
+		time2str ("%b %d %H:%M", str2time ($svn_date));
         }
 
         if ($self->{'fullpath'}) {
-	    my $dpath = $target->path_anchor;
+	    my $dpath = $target->{path};
 	    to_native ($dpath, 'path', $enc);
 	    $dpath .= '/' unless $dpath eq '/';
             print '/'.$target->depotname.$dpath;
@@ -81,7 +84,8 @@ sub _do_list {
 
 	if ($isdir && ($self->{recursive}) &&
 	    (!$self->{'depth'} ||( $level < $self->{'depth'} ))) {
-	    _do_list($self, $level+1, $target->new->descend($_));
+	    _do_list($self, $level+1, $target->new (path => "$target->{path}/$_",
+						    depotpath => "$target->{depotpath}/$_"));
 	}
     }
 }
