@@ -4,7 +4,7 @@ use SVK::Version;  our $VERSION = $SVK::VERSION;
 
 use base qw( SVK::Command::Commit );
 use SVK::I18N;
-use SVK::Util qw( is_uri get_prompt traverse_history );
+use SVK::Util qw( HAS_SVN_MIRROR is_uri get_prompt traverse_history );
 
 use constant narg => undef;
 
@@ -21,6 +21,7 @@ sub lock {} # override commit's locking
 
 sub parse_arg {
     my ($self, @arg) = @_;
+    die loc("cannot load SVN::Mirror") unless HAS_SVN_MIRROR;
 
     @arg = ('//') if $self->{upgrade} and !@arg;
     return if !@arg;
@@ -40,31 +41,34 @@ sub parse_arg {
 }
 
 sub run {
-    my ( $self, $target, $source, @options ) = @_;
-
-    SVK::Mirror->create(
-        {
-            depot   => $target->depot,
-            path    => $target->path,
-            backend => 'SVNRa',
-            url     => "$source", # this can be an URI object
-            pool    => SVN::Pool->new
-        }
-    );
-
-    print loc("Mirror initialized.  Run svk sync %1 to start mirroring.\n", $target->report);
-
+    my ($self, $target, $source, @options) = @_;
+    die loc ("%1 already exists.\n", $target->path)
+	if $target->root->check_path ($target->path);
+    $self->get_mirror_object ($target, $source, @options)->init
+	or die loc("%1 already mirrored, use 'svk mirror --detach' to remove it first.\n",
+		   $target->{depotpath});
     return;
 }
 
+sub get_mirror_object {
+    my ($self, $target, $source, @options) = @_;
+    return SVN::Mirror->new (target_path => $target->{path},
+			     source => $source,
+			     repospath => $target->{repospath},
+			     repos => $target->{repos},
+			     options => \@options,
+			     config => $self->{svnconfig},
+			     pool => SVN::Pool->new,
+			    );
+}
+
 package SVK::Command::Mirror::relocate;
 use base qw(SVK::Command::Mirror);
 use SVK::I18N;
 
 sub run {
     my ($self, $target, $source, @options) = @_;
-    $target->is_mirrored->relocate($source, @options);
-    print loc("Mirror relocated.\n");
+    $self->get_mirror_object ($target, $source, @options)->relocate;
     return;
 }
 
@@ -76,13 +80,14 @@ use constant narg => 1;
 
 sub run {
     my ($self, $target) = @_;
-    my ($m, $mpath) = $target->is_mirrored;
+    my ($m, $mpath) = SVN::Mirror::is_mirrored ($target->{repos},
+						$target->{path});
 
-    die loc("%1 is not a mirrored path.\n", $target->depotpath) if !$m;
-    die loc("%1 is inside a mirrored path.\n", $target->depotpath) if $mpath;
+    die loc("%1 is not a mirrored path.\n", $target->{depotpath}) if !$m;
+    die loc("%1 is inside a mirrored path.\n", $target->{depotpath}) if $mpath;
 
-    $m->detach(1); # remove svm:source and svm:uuid too
-    print loc("Mirror path '%1' detached.\n", $target->depotpath);
+    $m->delete(1); # remove svm:source and svm:uuid too
+    print loc("Mirror path '%1' detached.\n", $target->{depotpath});
     return;
 }
 
@@ -94,7 +99,7 @@ use constant narg => 1;
 
 sub run {
     my ($self, $target) = @_;
-    print loc("nothing to upgrade\n");
+    SVN::Mirror::upgrade ($target->{repos});
     return;
 }
 
@@ -106,54 +111,57 @@ use constant narg => 1;
 
 sub run {
     my ($self, $target) = @_;
-    $target->depot->mirror->unlock($target->path_anchor);
-    print loc ("mirror locks on %1 removed.\n", $target->report);
+    my $m = SVN::Mirror->new
+	( target_path => $target->path,
+	  repos => $target->{repos},
+	  ignore_lock => 1,
+	  get_source => 1
+	);
+    $m->init;
+    $m->unlock ('force');
+    print loc ("mirror locks on %1 removed.\n", $target->{report});
     return;
 }
 
 package SVK::Command::Mirror::list;
+use SVK::Util qw( HAS_SVN_MIRROR );
 use base qw(SVK::Command::Mirror);
 use SVK::I18N;
-use List::Util qw( max );
 
 sub parse_arg {
     my ($self, @arg) = @_;
+    die loc("cannot load SVN::Mirror") unless HAS_SVN_MIRROR;
     return (@arg ? @arg : undef);
 }
 
 sub run {
-    my ( $self, $target ) = @_;
-
-    my @mirror_columns;
-    my @depots
-        = defined $target
-        ? @_[ 1 .. $#_ ]
-        : sort keys %{ $self->{xd}{depotmap} }
-        ;
-    DEPOT:
-    foreach my $depot (@depots) {
-        $depot =~ s{/}{}g;
-        $target = eval { $self->arg_depotpath("/$depot/") };
-        if ($@) {
-            warn loc( "Depot /%1/ not loadable.\n", $depot );
-            next DEPOT;
-        }
-        my $depot_name = $target->depotname;
-        foreach my $path ( $target->depot->mirror->entries ) {
-            my $m = $target->depot->mirror->get($path);
-            push @mirror_columns, [ "/$depot_name$path", $m->url ];
-        }
-    }
-
-    my $max_depot_path = max map { length $_->[0] } @mirror_columns;
-    my $max_uri        = max map { length $_->[1] } @mirror_columns;
-
-    my $fmt = "%-${max_depot_path}s   %-s\n";
+    my ($self, $target) = @_;
+    my $fmt = "%-20s\t%-s\n";
     printf $fmt, loc('Path'), loc('Source');
-    print '=' x ( $max_depot_path + $max_uri + 3 ), "\n";
-
-    printf $fmt, @$_ for @mirror_columns;
-
+    print '=' x 60, "\n";
+    my @depots = (defined($_[1])) ? @_[1..$#_] : sort keys %{$self->{xd}{depotmap}};
+    foreach my $depot (@depots) {
+	$depot =~ s{/}{}g;
+	$target = eval { $self->arg_depotpath ("/$depot/") };
+	if ($@) {
+	    warn loc ("Depot /%1/ not loadable.\n", $depot);
+	    next;
+	}
+	my @paths = SVN::Mirror::list_mirror ($target->{repos});
+	my $fs = $target->{repos}->fs;
+	my $root = $fs->revision_root ($fs->youngest_rev);
+	my $name = $target->depotname;
+	foreach my $path (@paths) {
+	    eval {
+	    my $m = SVN::Mirror->new(
+                    target_path => $path,
+                    repos => $target->{repos},
+                    get_source => 1
+                );
+	    printf $fmt, "/$name$path", $m->{source};
+	    };
+	}
+    }
     return;
 }
 
@@ -166,9 +174,8 @@ use constant narg => 1;
 
 sub run {
     my ($self, $target, $source, @options) = @_;
-    die loc("recover not supported.\n");
-    my ($m, $mpath) = $target->is_mirrored;
-
+    $source = ("file://$target->{repospath}");
+    my $m = $self->get_mirror_object ($target, $source, @options);
     $self->recover_headrev ($target, $m);
     $self->recover_list_entry ($target, $m);
     return;
@@ -177,7 +184,7 @@ sub run {
 sub recover_headrev {
     my ($self, $target, $m) = @_;
 
-    my $fs = $target->repos->fs;
+    my $fs = $m->{fs};
     my ($props, $headrev, $rev, $firstrev, $skipped, $uuid, $rrev);
 
     traverse_history (
@@ -223,10 +230,9 @@ sub recover_headrev {
         delete => { direct => 1, message => '' }
     )->run($target);
 
-    $target->refresh_revision;
     $self->command(
-        copy => { direct  => 1, message => '' },
-    )->run($target->new(revision => $rev) => $target->new);
+        copy => { rev => $rev, direct  => 1, message => '' },
+    )->run($target => $target);
 
     # XXX - race condition? should get the last committed rev instead
     $target->refresh_revision;
@@ -242,7 +248,7 @@ sub recover_headrev {
 sub recover_list_entry {
     my ($self, $target, $m) = @_;
 
-    my %mirrors = map { ($_ => 1) } SVN::Mirror::list_mirror ($target->repos);
+    my %mirrors = map { ($_ => 1) } SVN::Mirror::list_mirror ($target->{repos});
 
     return if $mirrors{$m->{target_path}}++;
 
@@ -251,7 +257,7 @@ sub recover_list_entry {
         $self->arg_depotpath ('/'.$target->depotname.'/'),
     );
 
-    print loc("%1 added back to the list of mirrored paths.\n", $target->report);
+    print loc("%1 added back to the list of mirrored paths.\n", $target->{report}); 
     return;
 }
 
@@ -284,7 +290,7 @@ SVK::Command::Mirror - Initialize a mirrored depotpath
 
  -l [--list]            : list mirrored paths
  -d [--detach]          : mark a depotpath as no longer mirrored
- --relocate             : change the upstream URI for the mirrored depotpath
+ --relocate             : relocate the mirror to another URI
  --recover              : recover the state of a mirror path
  --unlock               : forcibly remove stalled locks on a mirror
  --upgrade              : upgrade mirror state to the latest version
