@@ -53,7 +53,7 @@ sub run {
     if (grep {$_->{copath}} @target) {
 	$self->ensure_parent($_) for @target;
 	for (@target) {
-	    make_path($_->{report}) or die $!;
+	    make_path($_->{report});
 	}
 	for (@target) {
 	    my $add = $self->command('add');
