@@ -206,7 +206,7 @@ SVK::Command::Patch - Manage patches
 
 =head1 OPTIONS
 
- None
+ --depot DEPOTNAME      : operate on a depot other than the default one
 
 =head1 DESCRIPTION
 
@@ -282,9 +282,13 @@ To see the current version of a specific patch, run:
     svk patch --view Foo
 
 When you're done with a patch and don't want it hanging around anymore,
-run
+run:
     svk patch --delete Foo
 
+To apply a patch to the repository that someone else has sent you, run:
+
+    svk patch --apply - < contributed_feature.patch
+
 =head1 AUTHORS
 
 Chia-liang Kao E<lt>clkao@clkao.orgE<gt>
