@@ -7,7 +7,6 @@ use SVK::XD;
 
 sub options {
    ('a|all'		=> 'all',
-    'force-incremental' => 'force_incremental',
     'l|lump'		=> 'lump');
 }
 
@@ -16,17 +15,14 @@ sub parse_arg {
 
     @arg = ('') if $#arg < 0;
 
-    # -- XXX -- will break otherwise -- XXX ---
-    # (Possibly fixed now, so we'll add an undocumented option to override
-    # this, to enable testing.)
-    $self->{lump} = 1 unless $self->{force_incremental};
+    $self->{lump} = 1; # -- XXX -- will break otherwise -- XXX ---
     $self->{incremental} = !$self->{lump};
 
     if ($self->{all}) {
         my $checkout = $self->{xd}{checkout}{hash};
         @arg = sort grep $checkout->{$_}{depotpath}, keys %$checkout;
     } 
-    elsif ( @arg == 1 and !$self->arg_co_maybe($arg[0])->isa('SVK::Path::Checkout')) {
+    elsif ( @arg == 1 and !$self->arg_co_maybe($arg[0])->{'copath'}) {
         # If the last argument is a depot path, rather than a copath
         # then we should do a merge to the local depot, rather than 
         # an update to the path
@@ -69,7 +65,7 @@ SVK::Command::Pull - Bring changes from another repository
 
  -a [--all]             : pull into all checkout paths
  -l [--lump]            : merge everything into a single commit log
-                          (always enabled by default for now)
+                          (always enabled for 'pull PATH' for now)
 
 =head1 AUTHORS
 
