@@ -3,7 +3,7 @@ use strict;
 use SVK::Version;  our $VERSION = $SVK::VERSION;
 
 require SVN::Delta;
-use base 'SVK::Editor::ByPass';
+our @ISA = qw(SVN::Delta::Editor);
 
 sub _open_pbaton {
     my ($self, $pbaton, $func) = @_;
