@@ -3,7 +3,7 @@ use strict;
 use SVK::Version;  our $VERSION = $SVK::VERSION;
 
 require SVN::Delta;
-use base 'SVK::Editor';
+our @ISA = qw(SVN::Delta::Editor);
 
 =head1 NAME
 
@@ -26,6 +26,15 @@ then the method name and its arguments.
 
 =cut
 
+sub baton_at {
+    my ($self, $func) = @_;
+    return -1
+	if $func eq 'set_target_revision' || $func eq 'open_root' ||
+	    $func eq 'close_edit' || $func eq 'abort_edit';
+    return 2 if $func eq 'delete_entry';
+    return $func =~ m/^(?:add|open|absent)/ ? 1 : 0;
+}
+
 sub AUTOLOAD {
     my ($self, @arg) = @_;
     my $func = our $AUTOLOAD;
@@ -43,7 +52,6 @@ sub AUTOLOAD {
     }
 
     my $ret = $func =~ m/^(?:add|open)/ ? ++$self->{batons} : undef;
-    Carp::cluck unless defined $func;
     push @{$self->{edit_tree}[$baton]}, [$ret, $func, @arg];
     return $ret;
 }
