@@ -80,7 +80,8 @@ sub AUTOLOAD {
     return if $func =~ m/^[A-Z]+$/;
     my $baton_at = $self->baton_at ($func);
     my ($renamed, $renamed_anchor);
-    if ($baton_at > 0) {
+
+    if ($baton_at == 1) {
 	my $newpath = $self->rename_check ($arg[0]);
 	if ($newpath ne $arg[0]) {
 	    ++$renamed;
@@ -99,10 +100,10 @@ sub AUTOLOAD {
     my $sfunc = "SUPER::$func";
     my $ret = $self->$sfunc (@arg);
 
-    $self->{renamed}[$ret]++ if $renamed && $ret;
+    $self->{renamed}[$ret]++ if $renamed;
 
     if ($renamed_anchor) {
-	push @{$self->{renamed_anchor}}, $self->{edit_tree}[$arg[$baton_at]][-1];
+	$self->{renamed_anchor}[$ret] = $self->{edit_tree}[$arg[1]][-1]
     }
     else {
 	$self->{opened_baton}{$arg[0]} = [$ret, $arg[1]]
@@ -123,8 +124,7 @@ sub open_parent {
 
     ++$self->{batons};
 
-    # XXX: If inspector is always there, then the first check isn't necessary.
-    if ($self->{inspector} && !$self->{inspector}->exist($parent)) {
+    if ($self->{cb_exist} && !$self->{cb_exist}->($parent)) {
 	unshift @{$self->{edit_tree}[$pbaton]},
 	    [$self->{batons}, 'add_directory', $parent, $ppbaton, undef, -1];
     }
@@ -148,10 +148,6 @@ sub adjust_anchor {
     @$entry = [];
 }
 
-sub adjust_last_anchor {
-    $_[0]->adjust_anchor($_[0]{edit_tree}[0][-1]);
-}
-
 sub _insert_entry {
     my ($self, $anchor, $entry) = @_;
     # move the call to a proper place.
@@ -167,22 +163,15 @@ sub _insert_entry {
 sub close_edit {
     my $self = shift;
     $self->SUPER::close_edit (@_);
-    for (@{$self->{renamed_anchor}}) {
-	$self->adjust_anchor($_);
+    for (0..$#{$self->{renamed_anchor}}) {
+	next unless defined $self->{renamed_anchor}[$_];
+	$self->adjust_anchor ($self->{renamed_anchor}[$_]);
     }
     # XXX: addition phase here to trim useless opens.
     $self->drive ($self->{editor});
 #SVN::Delta::Editor->new (_debug => 1, _editor => [$self->{editor}]));
 }
 
-# Make sure driven editor aborts too.
-sub abort_edit {
-    my $self = shift;
-    $self->SUPER::abort_edit (@_);
-    my $r = $self->{editor}->abort_edit(@_);
-    return $r;
-}
-
 =head1 AUTHORS
 
 Chia-liang Kao E<lt>clkao@clkao.orgE<gt>
