@@ -1,7 +1,7 @@
 package SVK::Editor::Sign;
 
 require SVN::Delta;
-use base 'SVK::Editor::ByPass';
+our @ISA = qw (SVN::Delta::Editor);
 use SVK::I18N;
 use autouse 'SVK::Util' => qw (tmpfile);
 
