@@ -5,7 +5,9 @@ use SVK::I18N;
 use SVK::Editor::Merge;
 use SVK::Editor::Rename;
 use SVK::Editor::Translate;
+use SVK::Editor::Delay;
 use List::Util qw(min);
+use SVK::Target::Universal;
 
 =head1 NAME
 
