@@ -37,6 +37,7 @@ info and anchor for the patch to be applied.
 =cut
 
 use SVK::Editor::Patch;
+use SVK::Util qw(find_svm_source find_local_mirror resolve_svm_source);
 use SVK::Merge;
 use SVK::Editor::Diff;
 use SVK::Target::Universal;
@@ -57,9 +58,10 @@ sub new {
     my $self = bless { name   => $name,
 		       level  => 0,
 		       _xd    => $xd,
+		       _depot => $depotname,
 		       _source => $src,
 		       _target => $dst }, $class;
-    $self->{_depot} = $self->{_xd}->find_depot($depotname);
+    (undef, undef, $self->{_repos}) = $self->{_xd}->find_repos ("/$self->{_depot}/", 1);
     $self->{source} = $self->{_source}->universal if $self->{_source};
     $self->{target} = $self->{_target}->universal;
     return $self;
@@ -96,14 +98,14 @@ sub load {
 
     my ($self) = thaw (uncompress (decode_base64 ( $content ) ) );
     $self->{_xd} = $xd;
-    $self->{_depot} = $self->{_xd}->find_depot($depot);
+    $self->{_depot} = $depot;
 
     my $not_applicable;
 
     for (qw/source target/) {
 	next unless $self->{$_};
-	my $tmp = $self->{"_$_"} = $self->{$_}->local($self->{_depot}) or next;
-	$tmp = $tmp->new->refresh_revision;
+	my $tmp = $self->{"_$_"} = $self->{$_}->local ($xd, $depot) or next;
+	$tmp = $tmp->new (revision => undef);
 	if (wantarray) {
 	    eval { $tmp->normalize };
 	    $not_applicable = $@
@@ -112,8 +114,9 @@ sub load {
 	    $tmp->normalize;
 	}
 	$self->{"_${_}_updated"} = 1
-	    if $tmp->{revision} > $self->{"_$_"}->revision;
+	    if $tmp->{revision} > $self->{"_$_"}->{revision};
     }
+    (undef, undef, $self->{_repos}) = $self->{_xd}->find_repos ("/$self->{_depot}/", 1);
     return wantarray ? ($self, $not_applicable) : $self;
 }
 
@@ -158,28 +161,31 @@ sub editor {
 sub _path_attribute_text {
     my ($self, $type, $no_label) = @_;
     # XXX: check if source / target is updated
-    my ($local, $m, $updated);
+    my ($local, $mirrored, $updated);
     if (my $target = $self->{"_$type"}) {
-	if ($target->repos->fs->get_uuid eq $self->{$type}{uuid}) {
+	if ($target->{repos}->fs->get_uuid eq $self->{$type}{uuid}) {
 	    ++$local;
 	}
 	else {
-	    $m= $target->is_mirrored or die;
+            my ($repos, $path) = @$target{qw/repos path/};
+            (undef, $mirrored) = resolve_svm_source(
+                $repos, find_svm_source($repos, $path)
+            );
 	}
     }
     my $label = $no_label ? '' : join(
 	' ', '',
 	($local ? '[local]' : ()),
-	($m? '[mirrored]' : ()),
+	($mirrored ? '[mirrored]' : ()),
 	($self->{"_${type}_updated"} ? '[updated]' : ())
     );
-    $label .= "\n        (".$m->url.")" if $m;
+    $label .= "\n        ($mirrored->{source})" if $mirrored;
     return $label;
 }
 
 sub view {
     my ($self, $output) = @_;
-    my $fs = $self->{_depot}->repos->fs;
+    my $fs = $self->{_repos}->fs;
 
     die loc("Target not local nor mirrored, unable to view patch.\n")
 	unless $self->{_target};
@@ -206,7 +212,14 @@ sub view {
     my $anchor = $self->{_target}->path;
     $self->editor->drive
 	( SVK::Editor::Diff->new
-	  ( base_target => $self->{_target}, base_root => $baseroot,
+	  ( cb_basecontent => sub { my ($path, $pool) = @_;
+				    my $base = $baseroot->file_contents ("$anchor/$path", $pool);
+				    return $base;
+				},
+	    cb_baseprop => sub { my ($path, $pname, $pool) = @_;
+				 return $baseroot->node_prop ("$anchor/$path", $pname, $pool);
+			     },
+	    oldtarget => $self->{_target}, oldroot => $baseroot,
 	    llabel => "revision $self->{target}{rev}",
 	    rlabel => "patch $self->{name} level $self->{level}",
 	    external => $ENV{SVKDIFF},
@@ -216,8 +229,8 @@ sub view {
 
 sub apply {
     my ($self, $check_only) = @_;
-    my $commit = SVK::Command->get_cmd ('commit', xd => $self->{_xd});
-    my $target = $self->{_target}->new->refresh_revision;
+    my $commit = SVK::Command->get_cmd ('commit', $self->{_xd});
+    my $target = $self->{_target};
     $commit->{message} = "Apply $self->{name}\@$self->{level}";
     $commit->{check_only} = $check_only;
     $self->apply_to ($target, $commit->get_editor ($target));
@@ -235,9 +248,9 @@ sub apply_to {
 	  anchor => $target->path,
 	  target => '',
 	  send_fulltext => !$cb{patch} && !$cb{mirror},
-	  ($target->isa('SVK::Path::Checkout')
+	  ($target->{copath}
 	      ? (notify => SVK::Notify->new_with_report
-		    ($target->report, $target, 1))
+		    ($target->{report}, $target, 1))
 	      : ()
 	  ),
 	  %cb,
@@ -253,14 +266,14 @@ sub update {
 	unless $self->{_target};
 
     return unless $self->{_target_updated};
-    my $target = $self->{_target}->new->refresh_revision;
+    my $target = $self->{_target}->new (revision => undef);
     $target->normalize;
     my $patch = SVK::Editor::Patch->new;
     my $conflict;
 
     if ($conflict = $self->apply_to ($target, $patch, patch => 1,
 				     SVK::Editor::Merge->cb_for_root
-				     ($target->root, $target->path, $target->revision))) {
+				     ($target->root, $target->path, $target->{revision}))) {
 
 	print loc("Conflicts.\n");
 	return $conflict;
@@ -280,16 +293,16 @@ sub regen {
 	print loc("Source of patch %1 not updated or not local, no need to regen patch.\n", $self->{name});
 	return;
     }
-    my $source = $self->{_source}->new->refresh_revision;
+    my $source = $self->{_source}->new (revision => undef);
     $source->normalize;
-    my $merge = SVK::Merge->auto (repos => $self->{_depot}->repos, xd => $self->{_xd},
+    my $merge = SVK::Merge->auto (repos => $self->{_repos}, xd => $self->{_xd},
 				  src => $source, dst => $target);
     my $conflict;
     my $patch = SVK::Editor::Patch->new;
     # XXX: handle empty
     unless ($conflict = $merge->run ($patch,
 				     SVK::Editor::Merge->cb_for_root
-				     ($target->root, $target->path, $target->revision))) {
+				     ($target->root, $target->path, $target->{revision}))) {
 	$self->{log} = $merge->log (1);
 	++$self->{level};
 	$self->{_source} = $source;
