@@ -5,7 +5,7 @@ use base 'SVK::Resolve';
 sub arguments {
     my $self = shift;
     return (
-        qw( -X -m -O -M ),
+        qw( -m -O -M ),
         @{$self}{qw( merged yours base theirs )}
     );
 }
