@@ -408,7 +408,10 @@ sub copied_from {
 sub report_copath {
     my ($self, $copath) = @_;
     my $report = length ($self->{report}) ? $self->{report} : undef;
-    abs2rel ($copath, $self->{copath} => $report);
+    my $rel = abs2rel( $copath, $self->{copath} => $report );
+    # XXX: abs2rel from F::S already does this.  tweak S::U abs2rel
+    # and usage properly
+    return length $rel ? $rel : '.';
 }
 
 =head1 AUTHORS
