@@ -27,12 +27,14 @@ use Config ();
 use SVK::I18N;
 use SVN::Core;
 use SVN::Ra;
-use autouse 'Encode'            => qw(resolve_alias decode encode);
+use autouse 'Encode'            => qw(resolve_alias($) decode encode);
 use File::Glob qw(bsd_glob);
 use autouse 'File::Basename' 	=> qw(dirname);
 use autouse 'File::Spec::Functions' => 
                                qw(catdir catpath splitpath splitdir tmpdir);
 
+use Class::Autouse qw( File::Type );
+
 
 =head1 NAME
 
@@ -457,8 +459,8 @@ Calculate MD5 checksum for data in the input filehandle.
 }
 
 sub md5_fh {
+    require Digest::MD5;
     my $fh = shift;
-
     my $ctx = Digest::MD5->new;
     $ctx->addfile($fh);
 
@@ -601,6 +603,9 @@ sub abs2rel {
         $rel = catdir($new_basedir, $rel);
     }
 
+    # resemble file::spec pre-3.13 behaviour, return empty string.
+    return '' if $rel eq '.';
+
     $rel =~ s/\Q$SEP/$sep/go if $sep and $SEP ne $sep;
     return $rel;
 }
