@@ -9,6 +9,7 @@ use SVK::Util qw( get_anchor abs_path abs_path_noexist abs2rel splitdir catdir s
 		  HAS_SYMLINK is_symlink is_executable mimetype mimetype_is_text
 		  md5_fh get_prompt traverse_history make_path dirname
 		  from_native to_native get_encoder get_depot_anchor );
+use Data::Hierarchy;
 use autouse 'File::Find' => qw(find);
 use autouse 'File::Path' => qw(rmtree);
 use autouse 'YAML'	 => qw(LoadFile DumpFile);
@@ -17,6 +18,8 @@ use PerlIO::eol 0.10 qw( NATIVE LF );
 use PerlIO::via::dynamic;
 use PerlIO::via::symlink;
 
+use Class::Autouse qw( SVK::Editor::XD SVK::Editor::Delay );
+
 
 =head1 NAME
 
@@ -336,6 +339,7 @@ sub find_repos {
     my ($depot, $path) = $depotpath =~ m|^/([^/]*)(/.*?)/?$|
 	or die loc("%1 is not a depot path.\n", $depotpath);
 
+    $path = File::Spec::Unix->canonpath($path);
     my $repospath = $self->{depotmap}{$depot} or die loc("No such depot: %1.\n", $depot);
 
     return ($repospath, $path, $open && _open_repos ($repospath));
@@ -406,6 +410,14 @@ sub find_depotname {
 
 sub condense {
     my $self = shift;
+
+    for (@_) {
+	if ($_ =~ m/([\x00-\x19\x7f])/) { # XXX: why isn't \c[ working?
+	    die loc("Invalid control character '%1' in path '%2'\n",
+		    sprintf("0x%02X", ord($1)), $_);
+	}
+    }
+
     my @targets = map {abs_path($_)} @_;
     my ($anchor, $report);
     for my $path (@_) {
@@ -419,7 +431,7 @@ sub condense {
 	my ($cinfo, $schedule) = $self->get_entry($anchor);
 	while (!-d $anchor || $cinfo->{scheduleanchor} ||
 	       $schedule eq 'add' || $schedule eq 'delete' || $schedule eq 'replace' ||
-	       ($anchor ne $copath && $anchor.$SEP ne substr ($copath, 0, length($anchor)+1))) {
+	       ($anchor ne $copath && $anchor ne $SEP && $anchor.$SEP ne substr ($copath, 0, length($anchor)+1))) {
 	    ($anchor, $report) = get_anchor (0, $anchor, $report);
 	    # XXX: put .. to report if it's anchorified beyond
 	    ($cinfo, $schedule) = $self->get_entry($anchor);
@@ -471,17 +483,20 @@ sub create_xd_root {
 
     my @paths = $self->{checkout}->find ($copath, {revision => qr'.*'});
 
-    return (undef, $fs->revision_root
-	    ($self->{checkout}->get ($paths[0] || $copath)->{revision}))
+    # In the simple case - only one revision entry found, it can be
+    # for some descendents.  If so we actually need to construct
+    # txnroot.
+    my ($simple, $revbase) = $self->{checkout}->get($paths[0] || $copath);
+    unshift @paths, $revbase unless $revbase eq $copath;
+    return (undef, $fs->revision_root($simple->{revision}))
 	if $#paths <= 0;
 
     my $pool = SVN::Pool->new;
-    my $base_rev;
     for (@paths) {
 	my $cinfo = $self->{checkout}->get ($_);
 	my $path = abs2rel($_, $copath => $arg{path}, '/');
 	unless ($root) {
-	    $base_rev = $cinfo->{revision};
+	    my $base_rev = $cinfo->{revision};
 	    $txn = $fs->begin_txn ($base_rev);
 	    $root = $txn->root();
 	    if ($base_rev == 0) {
@@ -495,7 +510,8 @@ sub create_xd_root {
 	    }
 	    next;
 	}
-	next if $cinfo->{revision} == $base_rev;
+	my ($parent) = get_anchor(0, $path);
+	next if $cinfo->{revision} == $root->node_created_rev($parent, $pool);
 	$root->delete ($path, $pool)
 	    if eval { $root->check_path ($path, $pool) != $SVN::Node::none };
 	SVN::Fs::revision_link ($fs->revision_root ($cinfo->{revision}, $pool),
@@ -949,10 +965,10 @@ sub _node_deleted {
     if ($arg{kind} == $SVN::Node::dir && $arg{delete_verbose}) {
 	foreach my $file (sort $self->{checkout}->find
 			  ($arg{copath}, {'.schedule' => 'delete'})) {
+	    next if $file eq $arg{copath};
 	    $file = abs2rel($file, $arg{copath} => undef, '/');
 	    from_native($file, 'path', $arg{encoder});
-	    $arg{editor}->delete_entry ("$arg{entry}/$file", @arg{qw/rev baton pool/})
-		if $file;
+	    $arg{editor}->delete_entry ("$arg{entry}/$file", @arg{qw/rev baton pool/});
 	}
     }
 }
